yakumo.neutron.v2.vpn.ipsec_policy.Manager

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module ipsec_policy :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for VPN IPSec policies in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for VPN IPSec policies in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.vpn.ipsec_policy.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, auth_algorithm=`'``__UNDEF__``'`, encryption_algorithm=`'``__UNDEF__``'`, pfs=`'``__UNDEF__``'`, lifetime=`'``__UNDEF__``'`, encapsulation_mode=`'``__UNDEF__``'`, transform_protocol=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) Create an IPSec policy | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``ike_policy``'``
| _json_resources_key = ``'``ike_policies``'``
| _url_resource_path = ``'``/v2.0/vpn/ike_policies``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, auth_algorithm=`'``__UNDEF__``'`, encryption_algorithm=`'``__UNDEF__``'`, pfs=`'``__UNDEF__``'`, lifetime=`'``__UNDEF__``'`, encapsulation_mode=`'``__UNDEF__``'`, transform_protocol=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) | source code
Create an IPSec policy Parameters: `name` (str) - IPSec policy name `description` (str) - Description `auth_algorithm` (str) - Auth algorithm; only 'sha1' `encryption_algorithm` (str) - Encryption algorithm ('3des', 'aes-128', 'aes-192', ...) `pfs` (str) - Perfect forward secrecy ('Group2', 'Group5', 'Group14', ...) `encapsulation_mode` (str) - Encapsulation mode 'tunnel' or 'transport' `lifetime` (str) - Life time; e.q.'3600seconds' `transform_protocol` (str) - Transform protocol 'ESP', 'AH', or 'AH-ESP' `project` (yakumo.project.Resource) - Project object Returns: yakumo.neutron.v2.vpn.ipsec_policy.Resource Created policy Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('auth_algorithm', 'auth_algorithm',
       mapper.Noop), ('encryption_algorithm', 'encryption_algorithm', mapper
      .Noop), ('pfs', 'pfs', mapper.Noop), ('lifetime', 'lifetime', mapper.N
      oop), ('encapsulation_mode', 'encapsulation_mode', mapper.Noop), ('tra
      nsform_protocol', 'transform_protocol', mapper.Noop), ('project', 'ten
      ant_id', mapper.Resource('project')),]